@@ -8,7 +8,7 @@ use Carp;
 use IO::File;
 require 5.004 ;
 
-$VERSION = '0.54';
+$VERSION = '0.55';
 
 #Global cache of modules we've loaded
 my %_MODULES;
@@ -560,10 +560,10 @@ Provides a unified interface to the various serializing modules
 currently available.  Adds the functionality of both compression
 and encryption. 
 
-By default Data::Serializer adds minor metadata and encodes serialized data
+By default L<Data::Serializer(3)> adds minor metadata and encodes serialized data
 structures in it's own format.  If you are looking for a simple unified
-pass through interface to the underlying serializers then look into Data::Serializer::Raw(3) 
-that comes bundled with Data::Serializer(3).
+pass through interface to the underlying serializers then look into L<Data::Serializer::Raw(3)> 
+that comes bundled with L<Data::Serializer(3)>.
 
 =head1 EXAMPLES
 
@@ -594,7 +594,7 @@ that comes bundled with Data::Serializer(3).
                         );
 
 
-B<new> is the constructor object for Data::Serializer objects.  
+B<new> is the constructor object for L<Data::Serializer(3)> objects.  
 
 =over 4
 
@@ -672,6 +672,9 @@ of the original serialized reference.
 This is a straight pass through to the underlying serializer,
 nothing else is done. (no encoding, encryption, compression, etc)
 
+If you desire this functionality you should look at L<Data::Serializer::Raw(3)> instead, it is 
+faster and leaner.
+
 =item B<raw_deserialize> - deserialize reference in raw form
 
   $deserialized = $obj->raw_deserialize($serialized);
@@ -679,11 +682,14 @@ nothing else is done. (no encoding, encryption, compression, etc)
 This is a straight pass through to the underlying serializer,
 nothing else is done. (no encoding, encryption, compression, etc)
 
+If you desire this functionality you should look at L<Data::Serializer::Raw(3)> instead, it is 
+faster and leaner.
+
 =item B<secret> - specify secret for use with encryption
 
   $obj->secret('mysecret');
 
-Changes setting of secret for the Data::Serializer object.  Can also be set
+Changes setting of secret for the L<Data::Serializer(3)> object.  Can also be set
 in the constructor.  If specified than the object will utilize encryption.
 
 =item B<portable> - encodes/decodes serialized data
@@ -702,46 +708,86 @@ Compresses serialized data.  Default is not to use it.  Will compress if set to
 Setting this to a true value will force serializer and deserializer to work in raw mode 
 (see raw_serializer and raw_deserializer).  The default is for this to be off.
 
+If you desire this functionality you should look at L<Data::Serializer::Raw(3)> instead, it is 
+faster and leaner.
+
 =item B<serializer> - change the serializer
 
-Currently have 8 supported serializers: Storable, FreezeThaw, Data::Denter, Config::General, YAML, 
-PHP::Serialization,  XML::Dumper, and Data::Dumper.
+Currently supports the following serializers: 
+
+=over 4
+
+=item L<Bencode(3)>
+
+=item L<Convert::Bencode(3)>
+
+=item L<Convert::Bencode_XS(3)>
+
+=item L<Config::General(3)>
+
+=item L<Data::Denter(3)>
+
+=item L<Data::Dumper(3)>
+
+=item L<Data::Taxi(3)>
+
+=item L<FreezeThaw(3)>
+
+=item L<JSON(3)>
+
+=item L<JSON::Syck(3)>
+
+=item L<PHP::Serialization(3)>
+
+=item L<Storable(3)>
+
+=item L<XML::Dumper(3)>
+
+=item L<XML::Simple(3)>
+
+=item L<YAML(3)>
+
+=item L<YAML::Syck(3)>
+
+=back
 
 Default is to use Data::Dumper.
 
+
+
 Each serializer has its own caveat's about usage especially when dealing with
 cyclical data structures or CODE references.  Please see the appropriate
 documentation in those modules for further information.
 
 =item B<cipher> - change the cipher method
 
-Utilizes Crypt::CBC and can support any cipher method that it supports.
+Utilizes L<Crypt::CBC(3)> and can support any cipher method that it supports.
 
 =item B<digester> - change digesting method
 
-Uses Digest so can support any digesting method that it supports.  Digesting
+Uses L<Digest(3)> so can support any digesting method that it supports.  Digesting
 function is used internally by the encryption routine as part of data verification.
 
 =item B<compressor> - changes compresing module
 
-Currently Compress::Zlib and Compress::PPMd are the only options
+Currently L<Compress::Zlib(3)> and L<Compress::PPMd(3)> are the only options
 
 =item B<encoding> - change encoding method
 
 Encodes data structure in ascii friendly manner.  Currently the only valid options
 are hex, or b64. 
 
-The b64 option uses Base64 encoding provided by MIME::Base64, but strips out newlines.
+The b64 option uses Base64 encoding provided by L<MIME::Base64(3)>, but strips out newlines.
 
 =item B<serializer_token> - add usage hint to data
 
-Data::Serializer prepends a token that identifies what was used to process its data.
-This is used internally to allow runtime determination of how to extract Serialized
-data.   Disabling this feature is not recommended.
+L<Data::Serializer(3)> prepends a token that identifies what was used to process its data.
+This is used internally to allow runtime determination of how to extract serialized
+data.  Disabling this feature is not recommended.   (Use L<Data::Serializer::Raw(3)> instead).
 
 =item B<options> - pass options through to underlying serializer
 
-Currently is only supported by Config::General, and XML::Dumper.  
+Currently is only supported by L<Config::General(3)>, and L<XML::Dumper(3)>.  
 
   my $obj = Data::Serializer->new(serializer => 'Config::General',
                                   options    => {
@@ -823,8 +869,8 @@ See http://www.perl.com/language/misc/Artistic.html
 
 =head1 ACKNOWLEDGEMENTS 
 
-Gurusamy Sarathy and Raphael Manfredi for writing MLDBM,
-the module which inspired the creation of Data::Serializer.
+Gurusamy Sarathy and Raphael Manfredi for writing L<MLDBM(3)>,
+the module which inspired the creation of L<Data::Serializer(3)>.
 
 And thanks to all of you who have provided the feedback 
 that has improved this module over the years.
@@ -840,30 +886,38 @@ This module is dedicated to my beautiful wife Erica.
 
 =over 4
 
-=item  L<Data::Dumper(3)>
+=item L<Bencode(3)>
 
-=item  L<Data::Denter(3)>
+=item L<Convert::Bencode(3)>
 
-=item  L<Data::Taxi(3)>
-
-=item L<Storable(3)>
-
-=item L<FreezeThaw(3)>
+=item L<Convert::Bencode_XS(3)>
 
 =item L<Config::General(3)>
 
-=item L<YAML(3)>
+=item L<Data::Denter(3)>
 
-=item L<YAML::Syck(3)>
+=item L<Data::Dumper(3)>
 
-=item L<PHP::Serialization(3)>
+=item L<Data::Taxi(3)>
 
-=item L<XML::Dumper(3)>
+=item L<FreezeThaw(3)>
 
 =item L<JSON(3)>
 
 =item L<JSON::Syck(3)>
 
+=item L<PHP::Serialization(3)>
+
+=item L<Storable(3)>
+
+=item L<XML::Dumper(3)>
+
+=item L<XML::Simple(3)>
+
+=item L<YAML(3)>
+
+=item L<YAML::Syck(3)>
+
 =item L<Compress::Zlib(3)>
 
 =item L<Compress::PPMd(3)>
@@ -872,12 +926,14 @@ This module is dedicated to my beautiful wife Erica.
 
 =item L<Digest::SHA(3)>
 
-=item L<Crypt(3)>
+=item L<Crypt::CBC(3)>
 
 =item L<MIME::Base64(3)>
 
 =item L<IO::File(3)>
 
+=item L<Data::Serializer::Config::Wrest(3)> - adds supports for L<Config::Wrest(3)>
+
 =back
 
 =cut
